.. _quadrature_collection:

Quadrature integration
======================

.. currentmodule:: chaospy.quadrature

Standard library
----------------

.. autosummary::
   :toctree: ../../api

   clenshaw_curtis
   fejer_1
   fejer_2
   gaussian
   grid
   legendre_proxy
   leja
   newton_cotes

Discrete densities
------------------

.. autosummary::
   :toctree: ../../api

   discrete

Gaussian extensions
-------------------

.. autosummary::
   :toctree: ../../api

   genz_keister_16
   genz_keister_18
   genz_keister_22
   genz_keister_24
   legendre
   kronrod
   lobatto
   patterson
   radau

Predefined Gaussian
-------------------

.. autosummary::
   :toctree: ../../api

   chebyshev_1
   chebyshev_2
   gegenbauer
   hermite
   jacobi
   legendre
   laguerre

Helper functions
----------------

.. autosummary::
   :toctree: ../../api

   sparse_grid
   kronrod_jacobi
